----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date: 09/29/2024 02:54:04 PM
-- Design Name: 
-- Module Name: neorv32Top_min - Behavioral
-- Project Name: 
-- Target Devices: 
-- Tool Versions: 
-- Description: 
-- 
-- Dependencies: 
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
-- 
----------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library neorv32;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx leaf cells in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity neorv32_top_min is
  port (
    -- Global control --
    clk_i  : in  std_logic;
    rstn_i : in  std_logic;
    -- PWM (available if IO_PWM_NUM_CH > 0) --
    pwm_o  : out std_ulogic_vector(3-1 downto 0);
      -- primary UART0 (available if IO_UART0_EN = true) --
    uart0_txd_o    : out std_ulogic;                                        -- UART0 send data
    uart0_rxd_i    : in  std_ulogic;                                 -- UART0 receive data
    uart0_rts_o    : out std_ulogic;                                        -- HW flow control: UART0.RX ready to receive ("RTR"), low-active, optional
    uart0_cts_i    : in  std_ulogic                                 -- HW flow control: UART0.TX allowed to transmit, low-active, optional
  );
end neorv32_top_min;

architecture Behavioral of neorv32_top_min is
  -- internal IO connection --
  signal con_pwm_o  : std_ulogic_vector(11 downto 0);
begin
  -- The core of the problem ----------------------------------------------------------------
  -- -------------------------------------------------------------------------------------------
  neorv32_inst: entity neorv32.neorv32_top
  generic map (
    -- General --
    CLOCK_FREQUENCY              => 100_000_000,   -- clock frequency of clk_i in Hz
    INT_BOOTLOADER_EN            => false,         -- boot configuration: true = boot explicit bootloader; false = boot from int/ext (I)MEM
    -- Internal Instruction memory --
    MEM_INT_IMEM_EN              => true,   -- implement processor-internal instruction memory
    MEM_INT_IMEM_SIZE            => 8*1024, -- size of processor-internal instruction memory in bytes
    -- Internal Data memory --
    MEM_INT_DMEM_EN              => true,   -- implement processor-internal data memory
    MEM_INT_DMEM_SIZE            => 64*1024, -- size of processor-internal data memory in bytes
    -- Processor peripherals --
    IO_MTIME_EN                  => true,  -- implement machine system timer (MTIME)?
    IO_PWM_NUM_CH                => 3,      -- number of PWM channels to implement (0..12); 0 = disabled
    IO_UART0_EN                  => true,       -- implement primary universal asynchronous receiver/transmitter (UART0)?
    
    -- CPU zxcfu use cfu extension --
    CPU_EXTENSION_RISCV_Zxcfu => true,   -- implement custom (instr.) functions unit?
    CPU_EXTENSION_RISCV_M => true       -- implement mul/div extension?
  )
  port map (
    -- Global control --
    clk_i  => clk_i,    -- global clock, rising edge
    rstn_i => rstn_i,   -- global reset, low-active, async
    -- PWM (available if IO_PWM_NUM_CH > 0) --
    pwm_o  => con_pwm_o, -- pwm channels
    
     -- primary UART0 (available if IO_UART0_EN = true) --
    uart0_txd_o    => uart0_txd_o,       -- UART0 send data
    uart0_rxd_i    => '0',       -- UART0 receive data
    uart0_rts_o    => uart0_rts_o,       -- HW flow control: UART0.RX ready to receive ("RTR"), low-active, optional
    uart0_cts_i    => '0'       -- HW flow control: UART0.TX allowed to transmit, low-active, optional
  );

  -- PWM --
  pwm_o <= con_pwm_o(3-1 downto 0);


end Behavioral;
